@@ -1,4 +1,4 @@
-# Copyright 2001-2016, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 use Devel::Cover::Criterion;
 use Devel::Cover::DB::File;
@@ -103,6 +103,7 @@ sub write {
     unless (mkdir $self->{db}) {
         croak "Can't mkdir $self->{db}: $!\n" unless -d $self->{db};
     }
+    chmod 0777, $self->{db} if $self->{loose_perms};
     $self->validate_db;
 
     my $db = { runs => $self->{runs} };
@@ -892,7 +893,7 @@ Devel::Cover::DB - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.24
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -911,7 +912,7 @@ This module provides access to a database of code coverage information.
 
  my $db = Devel::Cover::DB->new(db => "my_coverage_db");
 
-Contructs the DB from the specified database.
+Constructs the DB from the specified database.
 
 =head2 cover
 
@@ -978,7 +979,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2016, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
