@@ -1,4 +1,4 @@
-# Copyright 2011-2016, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,14 +10,13 @@ package Devel::Cover::DB::IO;
 use strict;
 use warnings;
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 my $Format;
 
 BEGIN {
     $Format = "Sereal"   if eval "use Sereal::Decoder; use Sereal::Encoder; 1";
-    $Format = "JSON"     if !$Format and eval "use JSON; 1";
-    $Format = "JSON"     if !$Format and eval "use JSON::PP; 1";
+    $Format = "JSON"     if !$Format and eval { require JSON::MaybeXS; 1 };
     $Format = "Storable" if !$Format and eval "use Storable; 1";
     die "Can't load either JSON or Storable" unless $Format;
 }
@@ -46,7 +45,7 @@ Devel::Cover::DB::IO - IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.24
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -70,7 +69,7 @@ This module provides IO routines for Devel::Cover::DB.
 
  my $io = Devel::Cover::DB::IO->new(format => "JSON");
 
-Contructs the IO object.
+Constructs the IO object.
 
 =head2 read
 
@@ -90,7 +89,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2016, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
