@@ -1,4 +1,4 @@
-# Copyright 2011-2016, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,7 +12,7 @@ use warnings;
 
 use Storable;
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 sub new {
     my $class = shift;
@@ -29,6 +29,8 @@ sub read {
 sub write {
     my $self = shift;
     my ($data, $file) = @_;
+
+    unlink $file;
     Storable::lock_nstore($data, $file);
     $self
 }
@@ -43,7 +45,7 @@ Devel::Cover::DB::IO::Storable - Storable based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.24
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -67,7 +69,7 @@ This module provides Storable based IO routines for Devel::Cover::DB.
 
  my $io = Devel::Cover::DB::IO::Storable->new;
 
-Contructs the IO object.
+Constructs the IO object.
 
 =head2 read
 
@@ -87,7 +89,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2016, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
